@@ -13,7 +13,7 @@
 #include <version.h>
 
 #ifndef Q_OS_WIN
-#include <signal.h>
+#include <csignal>
 
 void signalhandler(int sig)
 {
@@ -25,6 +25,7 @@ void signalhandler(int sig)
 #endif
 
 using namespace bt;
+using namespace Qt::Literals::StringLiterals;
 
 int main(int argc, char **argv)
 {
@@ -37,7 +38,7 @@ int main(int argc, char **argv)
             return -1;
         }
 
-        QCoreApplication::setApplicationName("ktcli");
+        QCoreApplication::setApplicationName(u"ktcli"_s);
         QCoreApplication::setApplicationVersion(bt::GetVersionString());
 
         KTCLI app(argc, argv);
