@@ -6,8 +6,8 @@
 #ifndef BTBDECODER_H
 #define BTBDECODER_H
 
+#include <QString>
 #include <ktorrent_export.h>
-#include <qstring.h>
 #include <util/constants.h>
 
 namespace bt
