@@ -4,7 +4,6 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "database.h"
-#include <arpa/inet.h>
 #include <torrent/globals.h>
 #include <util/functions.h>
 #include <util/log.h>
@@ -14,20 +13,20 @@ using namespace bt;
 namespace dht
 {
 DBItem::DBItem()
+    : time_stamp(bt::CurrentTime())
 {
-    time_stamp = bt::CurrentTime();
 }
 
 DBItem::DBItem(const net::Address &addr)
     : addr(addr)
+    , time_stamp(bt::CurrentTime())
 {
-    time_stamp = bt::CurrentTime();
 }
 
 DBItem::DBItem(const DBItem &it)
+    : addr(it.addr)
+    , time_stamp(it.time_stamp)
 {
-    addr = it.addr;
-    time_stamp = it.time_stamp;
 }
 
 DBItem::~DBItem()
