@@ -7,13 +7,16 @@
 
 #include <config-ktorrent.h>
 
+#include <KFileItem>
+#include <KLocalizedString>
+
+#include <QFile>
+#include <QStorageInfo>
+
 #include "cache.h"
 #include "preallocationthread.h"
-#include <errno.h>
+#include <cerrno>
 #include <fcntl.h>
-#include <kfileitem.h>
-#include <klocalizedstring.h>
-#include <qfile.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <util/array.h>
@@ -26,8 +29,6 @@
 #include <sys/mman.h>
 #endif
 
-#include <QStorageInfo>
-
 // Not all systems have an O_LARGEFILE - Solaris depending
 // on command-line defines, FreeBSD never - so in those cases,
 // make it a zero bitmask. As long as it's only OR'ed into
@@ -37,6 +38,8 @@
 #define O_LARGEFILE (0)
 #endif
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 CacheFile::CacheFile()
@@ -75,7 +78,7 @@ void CacheFile::openFile(Mode mode)
     if (!ok) {
         delete fptr;
         fptr = nullptr;
-        throw Error(i18n("Cannot open %1: %2", path, strerror(errno)));
+        throw Error(i18n("Cannot open %1: %2", path, QString::fromUtf8(strerror(errno))));
     }
 
     file_size = fptr->size();
@@ -150,7 +153,7 @@ void *CacheFile::map(MMappeable *thing, Uint64 off, Uint32 size, Mode mode)
         char *ptr = (char *)mmap(0, size + diff, mmap_flag, MAP_SHARED, fd, noff);
 #endif
         if (ptr == MAP_FAILED) {
-            Out(SYS_DIO | LOG_DEBUG) << "mmap failed : " << QString(strerror(errno)) << endl;
+            Out(SYS_DIO | LOG_DEBUG) << "mmap failed : " << QString::fromUtf8(strerror(errno)) << endl;
             return nullptr;
         } else {
             CacheFile::Entry e;
@@ -170,7 +173,7 @@ void *CacheFile::map(MMappeable *thing, Uint64 off, Uint32 size, Mode mode)
         void *ptr = mmap(0, size, mmap_flag, MAP_SHARED, fd, off);
 #endif
         if (ptr == MAP_FAILED) {
-            Out(SYS_DIO | LOG_DEBUG) << "mmap failed : " << QString(strerror(errno)) << endl;
+            Out(SYS_DIO | LOG_DEBUG) << "mmap failed : " << QString::fromUtf8(strerror(errno)) << endl;
             return nullptr;
         } else {
             CacheFile::Entry e;
@@ -188,7 +191,7 @@ void *CacheFile::map(MMappeable *thing, Uint64 off, Uint32 size, Mode mode)
     char *ptr = (char *)fptr->map(off, size);
 
     if (!ptr) {
-        Out(SYS_DIO | LOG_DEBUG) << "mmap failed3 : " << fptr->handle() << " " << QString(strerror(errno)) << endl;
+        Out(SYS_DIO | LOG_DEBUG) << "mmap failed3 : " << fptr->handle() << " " << QString::fromUtf8(strerror(errno)) << endl;
         Out(SYS_DIO | LOG_DEBUG) << off << " " << size << endl;
         return 0;
     } else {
@@ -228,7 +231,7 @@ void CacheFile::growFile(Uint64 to_write)
     file_size = fptr->size();
 }
 
-void CacheFile::unmap(void *ptr, Uint32 size)
+void CacheFile::unmap(void *ptr)
 {
     int ret = 0;
     QMutexLocker lock(&mutex);
@@ -239,7 +242,7 @@ void CacheFile::unmap(void *ptr, Uint32 size)
     if (mappings.contains(ptr)) {
         CacheFile::Entry &e = mappings[ptr];
         if (!fptr->unmap((uchar *)e.ptr))
-            Out(SYS_DIO | LOG_IMPORTANT) << QString("Unmap failed : %1").arg(fptr->errorString()) << endl;
+            Out(SYS_DIO | LOG_IMPORTANT) << u"Unmap failed : %1"_s.arg(fptr->errorString()) << endl;
 
         mappings.remove(ptr);
         // no mappings, close temporary
@@ -256,7 +259,7 @@ void CacheFile::unmap(void *ptr, Uint32 size)
         ret = munmap(e.ptr, e.size);
 #endif
         if (ret < 0)
-            Out(SYS_DIO | LOG_IMPORTANT) << QString("Munmap failed with error %1 : %2").arg(errno).arg(strerror(errno)) << endl;
+            Out(SYS_DIO | LOG_IMPORTANT) << u"Munmap failed with error %1 : %2"_s.arg(errno).arg(QString::fromUtf8(strerror(errno))) << endl;
 
         mappings.remove(ptr);
         // no mappings, close temporary
@@ -302,7 +305,7 @@ void CacheFile::unmapAll()
         ++i;
         mappings.remove(e.ptr);
         if (ret < 0) {
-            Out(SYS_DIO | LOG_IMPORTANT) << QString("Munmap failed with error %1 : %2").arg(errno).arg(strerror(errno)) << endl;
+            Out(SYS_DIO | LOG_IMPORTANT) << u"Munmap failed with error %1 : %2"_s.arg(errno).arg(QString::fromUtf8(strerror(errno))) << endl;
         }
     }
 }
@@ -442,7 +445,7 @@ void CacheFile::preallocate(PreallocationThread *prealloc)
             bt::TruncateFile(fd, max_size, !Cache::preallocateFully());
         }
     } catch (bt::Error &e) {
-        throw Error(i18n("Cannot preallocate diskspace: %1", strerror(errno)));
+        throw Error(i18n("Cannot preallocate diskspace: %1", QString::fromUtf8(strerror(errno))));
     }
 
     file_size = FileSize(fd);
