@@ -4,13 +4,17 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "multifilecache.h"
+
+#include <cerrno>
+
+#include <KLocalizedString>
+
+#include <QDir>
+#include <QFileInfo>
 #include <QSet>
+#include <QStringList>
 #include <QTextStream>
-#include <errno.h>
-#include <klocalizedstring.h>
-#include <qdir.h>
-#include <qfileinfo.h>
-#include <qstringlist.h>
+
 #include <util/error.h>
 #include <util/file.h>
 #include <util/fileops.h>
@@ -29,6 +33,8 @@
 #include "preallocationthread.h"
 #include <torrent/torrent.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 static Uint64 FileOffset(Chunk *c, const TorrentFile &f, Uint64 chunk_size);
@@ -39,7 +45,7 @@ MultiFileCache::MultiFileCache(Torrent &tor, const QString &tmpdir, const QStrin
     : Cache(tor, tmpdir, datadir)
     , opened(false)
 {
-    cache_dir = tmpdir + "cache" + bt::DirSeparator();
+    cache_dir = tmpdir + "cache"_L1 + bt::DirSeparator();
 
     if (!custom_output_name)
         output_dir = this->datadir + tor.getNameSuggestion() + bt::DirSeparator();
@@ -54,7 +60,7 @@ MultiFileCache::~MultiFileCache()
 
 void MultiFileCache::loadFileMap()
 {
-    QString file_map = tmpdir + "file_map";
+    QString file_map = tmpdir + "file_map"_L1;
     if (!bt::Exists(file_map)) {
         // file map doesn't exist, so just set the path on disk if it has not happened yet
         Uint32 num = tor.getNumFiles();
@@ -65,7 +71,7 @@ void MultiFileCache::loadFileMap()
         }
         saveFileMap();
     } else {
-        QFile fptr(tmpdir + "file_map");
+        QFile fptr(tmpdir + "file_map"_L1);
         if (!fptr.open(QIODevice::ReadOnly))
             throw Error(i18n("Failed to open %1: %2", file_map, fptr.errorString()));
 
@@ -89,7 +95,7 @@ void MultiFileCache::loadFileMap()
 
 void MultiFileCache::saveFileMap()
 {
-    QString file_map = tmpdir + "file_map";
+    QString file_map = tmpdir + "file_map"_L1;
     QFile fptr(file_map);
     if (!fptr.open(QIODevice::WriteOnly))
         throw Error(i18n("Failed to create %1: %2", file_map, fptr.errorString()));
@@ -128,7 +134,7 @@ void MultiFileCache::open()
     if (opened)
         return;
 
-    QString dnd_dir = tmpdir + "dnd" + bt::DirSeparator();
+    QString dnd_dir = tmpdir + "dnd"_L1 + bt::DirSeparator();
     // open all files
     for (Uint32 i = 0; i < tor.getNumFiles(); i++) {
         TorrentFile &tf = tor.getFile(i);
@@ -143,12 +149,12 @@ void MultiFileCache::open()
             if (dnd_files.contains(i))
                 dnd_files.remove(i);
 
-            QString dnd_path = QString("file%1.dnd").arg(tf.getIndex());
+            QString dnd_path = u"file%1.dnd"_s.arg(tf.getIndex());
             QString dnd_file = dnd_dir + dnd_path;
-            if (bt::Exists(dnd_dir + tf.getUserModifiedPath() + ".dnd")) {
+            if (bt::Exists(dnd_dir + tf.getUserModifiedPath() + ".dnd"_L1)) {
                 // old style dnd dir, move the file so that we can keep working
                 // with the old file
-                bt::Move(dnd_dir + tf.getUserModifiedPath() + ".dnd", dnd_file, true, true);
+                bt::Move(dnd_dir + tf.getUserModifiedPath() + ".dnd"_L1, dnd_file, true, true);
             }
             DNDFile::Ptr dfd(new DNDFile(dnd_file, &tf, tor.getChunkSize()));
             dfd->checkIntegrity();
@@ -162,7 +168,7 @@ void MultiFileCache::open()
 void MultiFileCache::changeTmpDir(const QString &ndir)
 {
     Cache::changeTmpDir(ndir);
-    QString dnd_dir = tmpdir + "dnd" + bt::DirSeparator();
+    QString dnd_dir = tmpdir + "dnd"_L1 + bt::DirSeparator();
 
     // change paths for individual files, it should not
     // be a problem to move these files when they are open
@@ -171,7 +177,7 @@ void MultiFileCache::changeTmpDir(const QString &ndir)
         if (tf.doNotDownload()) {
             DNDFile::Ptr dfd = dnd_files[i];
             if (dfd) {
-                QString dnd_path = QString("file%1.dnd").arg(tf.getIndex());
+                QString dnd_path = u"file%1.dnd"_s.arg(tf.getIndex());
                 dfd->changePath(dnd_dir + dnd_path);
             }
         }
@@ -293,8 +299,8 @@ void MultiFileCache::create()
 {
     if (!bt::Exists(output_dir))
         MakeDir(output_dir);
-    if (!bt::Exists(tmpdir + "dnd"))
-        bt::MakeDir(tmpdir + "dnd");
+    if (!bt::Exists(tmpdir + "dnd"_L1))
+        bt::MakeDir(tmpdir + "dnd"_L1);
 
     QSet<QString> mount_points;
     QSet<QString> shortened_names;
@@ -568,16 +574,16 @@ void MultiFileCache::savePiece(PieceData::Ptr piece)
 void MultiFileCache::downloadStatusChanged(TorrentFile *tf, bool download)
 {
     bool dnd = !download;
-    QString dnd_dir = tmpdir + "dnd" + bt::DirSeparator();
-    QString dnd_path = QString("file%1.dnd").arg(tf->getIndex());
+    QString dnd_dir = tmpdir + "dnd"_L1 + bt::DirSeparator();
+    QString dnd_path = u"file%1.dnd"_s.arg(tf->getIndex());
     QString dnd_file = dnd_dir + dnd_path;
     // if it is dnd and it is already in the dnd tree do nothing
     if (dnd && bt::Exists(dnd_dir + dnd_path))
         return;
-    else if (dnd && bt::Exists(dnd_dir + tf->getUserModifiedPath() + ".dnd")) {
+    else if (dnd && bt::Exists(dnd_dir + tf->getUserModifiedPath() + ".dnd"_L1)) {
         // old style dnd dir, move the file so that we can keep working
         // with the old file
-        bt::Move(dnd_dir + tf->getUserModifiedPath() + ".dnd", dnd_file, true, true);
+        bt::Move(dnd_dir + tf->getUserModifiedPath() + ".dnd"_L1, dnd_file, true, true);
         return;
     }
 
@@ -617,7 +623,7 @@ void MultiFileCache::saveFirstAndLastChunk(TorrentFile *tf, const QString &src_f
 {
     DNDFile out(dst_file, tf, tor.getChunkSize());
     File fptr;
-    if (!fptr.open(src_file, "rb"))
+    if (!fptr.open(src_file, u"rb"_s))
         throw Error(i18n("Cannot open file %1: %2", src_file, fptr.errorString()));
 
     Uint32 cs = (tf->getFirstChunk() == tor.getNumChunks() - 1) ? tor.getLastChunkSize() : tor.getChunkSize();
@@ -652,7 +658,7 @@ void MultiFileCache::recreateFile(TorrentFile *tf, const QString &dnd_file, cons
     Uint32 cs = (tf->getFirstChunk() == tor.getNumChunks() - 1) ? tor.getLastChunkSize() : tor.getChunkSize();
 
     File fptr;
-    if (!fptr.open(output_file, "r+b"))
+    if (!fptr.open(output_file, u"r+b"_s))
         throw Error(i18n("Cannot open file %1: %2", output_file, fptr.errorString()));
 
     Uint32 ts = cs - tf->getFirstChunkOffset() > tf->getLastChunkSize() ? cs - tf->getFirstChunkOffset() : tf->getLastChunkSize();
@@ -725,10 +731,7 @@ static void DeleteEmptyDirs(const QString &output_dir, const QString &fpath)
             path += s + bt::DirSeparator();
 
         QDir dir(path);
-        QStringList el = dir.entryList(QDir::AllEntries | QDir::System | QDir::Hidden);
-        el.removeAll(".");
-        el.removeAll("..");
-        if (el.count() == 0 && dir.exists()) {
+        if (dir.exists() && dir.isEmpty(QDir::AllEntries | QDir::System | QDir::Hidden | QDir::NoDotAndDotDot)) {
             // no childern so delete the directory
             Out(SYS_GEN | LOG_DEBUG) << "Deleting empty directory : " << path << endl;
             bt::Delete(path, true);
@@ -741,10 +744,7 @@ static void DeleteEmptyDirs(const QString &output_dir, const QString &fpath)
 
     // now the output_dir itself
     QDir dir(output_dir);
-    QStringList el = dir.entryList(QDir::AllEntries | QDir::System | QDir::Hidden);
-    el.removeAll(".");
-    el.removeAll("..");
-    if (el.count() == 0 && dir.exists()) {
+    if (dir.exists() && dir.isEmpty(QDir::AllEntries | QDir::System | QDir::Hidden | QDir::NoDotAndDotDot)) {
         Out(SYS_GEN | LOG_DEBUG) << "Deleting empty directory : " << output_dir << endl;
         bt::Delete(output_dir, true);
     }
