@@ -11,6 +11,8 @@
 #include <util/error.h>
 #include <util/log.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 MagnetLink::MagnetLink()
@@ -60,7 +62,7 @@ bool MagnetLink::operator==(const bt::MagnetLink &mlink) const
 static QList<QUrl> GetTrackers(const QUrl &url)
 {
     QList<QUrl> result;
-    for (QString tr : QUrlQuery(url).allQueryItemValues("tr", QUrl::FullyDecoded))
+    for (QString tr : QUrlQuery(url).allQueryItemValues(u"tr"_s, QUrl::FullyDecoded))
         result << QUrl(tr.replace(QLatin1Char('+'), QLatin1Char(' ')));
     return result;
 }
@@ -90,7 +92,7 @@ void MagnetLink::parse(const QUrl &url)
         const QRegularExpressionMatch match = btihHash.match(url.host());
 
         if (match.hasMatch()) {
-            QString primaryHash = match.captured(1).split('-')[0];
+            QString primaryHash = match.captured(1).split('-'_L1)[0];
             xt = QLatin1String("urn:btih:") + primaryHash;
         } else {
             Out(SYS_GEN | LOG_NOTICE) << "No hash found in magnet link " << url << endl;
@@ -118,7 +120,7 @@ void MagnetLink::parse(const QUrl &url)
 
         info_hash = SHA1Hash(hash);
         tracker_urls = GetTrackers(url);
-        name = QUrlQuery(url).queryItemValue(QLatin1String("dn")).replace('+', ' ');
+        name = QUrlQuery(url).queryItemValue(QLatin1String("dn")).replace('+'_L1, ' '_L1);
         magnet_string = url.toString();
     } catch (...) {
         Out(SYS_GEN | LOG_NOTICE) << "Invalid magnet link " << url << endl;
@@ -131,7 +133,7 @@ Uint8 MagnetLink::charToHex(const QChar &ch)
         return ch.digitValue();
 
     if (!ch.isLetter())
-        throw bt::Error("Invalid char");
+        throw bt::Error(u"Invalid char"_s);
 
     if (ch.isLower())
         return 10 + ch.toLatin1() - 'a';
@@ -153,7 +155,7 @@ QString MagnetLink::base32ToHexString(const QString &s)
         for (int j = 0; j < 4; j++) {
             ch = str[i * 4 + j];
             if (ch.isDigit() && (ch.digitValue() < 2 || ch.digitValue() > 7))
-                throw bt::Error("Invalid char");
+                throw bt::Error(u"Invalid char"_s);
 
             if (ch.isDigit())
                 tmp = ch.digitValue() + 24;
