@@ -5,8 +5,8 @@
 */
 #include "encryptedpacketsocket.h"
 #include <QtGlobal>
-#include <errno.h>
-#include <stdlib.h>
+#include <cerrno>
+#include <cstdlib>
 #include <sys/types.h>
 #include <util/log.h>
 #include <util/sha1hash.h>
