@@ -6,7 +6,6 @@
 #ifndef NETSPEED_H
 #define NETSPEED_H
 
-#include <QLinkedList>
 #include <QPair>
 #include <deque>
 #include <util/constants.h>
@@ -22,11 +21,8 @@ class Speed
 {
     QAtomicInt rate;
     bt::Uint32 bytes;
-#ifndef DO_NOT_USE_DEQUE
     std::deque<QPair<bt::Uint32, bt::TimeStamp>> dlrate;
-#else
-    QLinkedList<QPair<bt::Uint32, bt::TimeStamp>> dlrate;
-#endif
+
 public:
     Speed();
     virtual ~Speed();
