@@ -5,21 +5,24 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "torrent.h"
-#include <QTextCodec>
+
+#include <QDataStream>
+#include <QFile>
+#include <QStringList>
+
 #include <bcodec/bdecoder.h>
 #include <bcodec/bnode.h>
+#include <cstdlib>
+#include <ctime>
 #include <interfaces/monitorinterface.h>
-#include <qdatastream.h>
-#include <qfile.h>
-#include <qstringlist.h>
-#include <stdlib.h>
-#include <time.h>
 #include <util/error.h>
 #include <util/functions.h>
 #include <util/log.h>
 #include <util/sha1hashgen.h>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
+
+using namespace Qt::Literals::StringLiterals;
 
 namespace bt
 {
@@ -27,19 +30,19 @@ static QString SanityzeName(const QString &name)
 {
     QString ret = name;
 #ifdef Q_OS_WIN
-    char invalid[] = {'<', '>', ':', '"', '/', '\\', '|', '?', '*'};
+    const QLatin1Char invalid[] = {'<'_L1, '>'_L1, ':'_L1, '"'_L1, '/'_L1, '\\'_L1, '|'_L1, '?'_L1, '*'_L1};
     for (int i = 0; i < 9; i++) {
         if (ret.contains(invalid[i]))
-            ret = ret.replace(invalid[i], '_');
+            ret = ret.replace(invalid[i], '_'_L1);
     }
 #else
-    if (ret.endsWith('/'))
+    if (ret.endsWith('/'_L1))
         ret.chop(1);
-    if (ret.startsWith('/'))
+    if (ret.startsWith('/'_L1))
         ret = ret.mid(1);
 #endif
     // Don't allow directory traversal things in names
-    if (ret.contains('/') || ret.contains(QLatin1String(".."))) {
+    if (ret.contains('/'_L1) || ret.contains(".."_L1)) {
         QStringList sl = ret.split(bt::DirSeparator());
         sl.removeAll(QLatin1String(".."));
         ret = sl.join(QStringLiteral("_"));
@@ -53,7 +56,6 @@ Torrent::Torrent()
     , chunk_size(0)
     , last_chunk_size(0)
     , total_size(0)
-    , text_codec(QTextCodec::codecForName("utf-8"))
     , file_prio_listener(nullptr)
     , pos_cache_chunk(0)
     , pos_cache_file(0)
@@ -69,7 +71,6 @@ Torrent::Torrent(const bt::SHA1Hash &hash)
     , chunk_size(0)
     , last_chunk_size(0)
     , total_size(0)
-    , text_codec(QTextCodec::codecForName("utf-8"))
     , file_prio_listener(nullptr)
     , pos_cache_chunk(0)
     , pos_cache_file(0)
@@ -95,19 +96,9 @@ void Torrent::load(const QByteArray &data, bool verbose)
         if (!dict)
             throw Error(i18n("Corrupted torrent."));
 
-        // see if we can find an encoding node
-        if (dict->getValue(QByteArrayLiteral("encoding"))) {
-            QByteArray enc = dict->getByteArray(QByteArrayLiteral("encoding"));
-            QTextCodec *tc = QTextCodec::codecForName(enc);
-            if (tc) {
-                Out(SYS_GEN | LOG_DEBUG) << "Encoding : " << QString(tc->name()) << endl;
-                text_codec = tc;
-            }
-        }
-
         BValueNode *c = dict->getValue(QByteArrayLiteral("comment"));
         if (c)
-            comments = c->data().toString(text_codec);
+            comments = c->data().toString();
 
         const BValueNode *announce = dict->getValue(QByteArrayLiteral("announce"));
         BListNode *nodes = dict->getList(QByteArrayLiteral("nodes"));
@@ -115,7 +106,7 @@ void Torrent::load(const QByteArray &data, bool verbose)
         //  throw Error(i18n("Torrent has no announce or nodes field."));
 
         if (announce)
-            loadTrackerURL(dict->getString(QByteArrayLiteral("announce"), text_codec));
+            loadTrackerURL(dict->getString(QByteArrayLiteral("announce")));
 
         if (nodes) // DHT torrrents have a node key
             loadNodes(nodes);
@@ -128,7 +119,7 @@ void Torrent::load(const QByteArray &data, bool verbose)
         if (urls) {
             loadWebSeeds(urls);
         } else if (dict->getValue(QByteArrayLiteral("url-list"))) {
-            QUrl url(dict->getString(QByteArrayLiteral("url-list"), text_codec));
+            QUrl url(dict->getString(QByteArrayLiteral("url-list")));
             if (url.isValid())
                 web_seeds.append(url);
         }
@@ -137,7 +128,7 @@ void Torrent::load(const QByteArray &data, bool verbose)
         SHA1HashGen hg;
         // save info dict
         metadata = data.mid(n->getOffset(), n->getLength());
-        info_hash = hg.generate((const Uint8 *)metadata.data(), metadata.size());
+        info_hash = hg.generate(metadata);
         delete node;
 
         loaded = true;
@@ -161,7 +152,7 @@ void Torrent::loadInfo(BDictNode *dict)
 
     loadHash(dict);
     unencoded_name = dict->getByteArray(QByteArrayLiteral("name"));
-    name_suggestion = text_codec->toUnicode(unencoded_name);
+    name_suggestion = QString::fromUtf8(unencoded_name);
     name_suggestion = SanityzeName(name_suggestion);
     BValueNode *n = dict->getValue(QByteArrayLiteral("private"));
     if (n && n->data().toInt() == 1)
@@ -202,9 +193,9 @@ void Torrent::loadFiles(BListNode *node)
         for (Uint32 j = 0; j < ln->getNumChildren(); j++) {
             QByteArray v = ln->getByteArray(j);
             unencoded_path.append(v);
-            QString sd = text_codec ? text_codec->toUnicode(v) : QString(v);
-            if (sd.contains(QLatin1String("\n")))
-                sd = sd.remove(QLatin1String("\n"));
+            QString sd = QString::fromUtf8(v);
+            if (sd.contains('\n'_L1))
+                sd = sd.remove('\n'_L1);
             path += sd;
             if (j + 1 < ln->getNumChildren())
                 path += bt::DirSeparator();
@@ -240,11 +231,10 @@ void Torrent::loadTrackerURL(const QString &s)
 
 void Torrent::loadHash(BDictNode *dict)
 {
-    QByteArray hash_string = dict->getByteArray(QByteArrayLiteral("pieces"));
+    const QByteArray hash_string = dict->getByteArray(QByteArrayLiteral("pieces"));
+    const QByteArrayView hash_string_view{hash_string};
     for (int i = 0; i < hash_string.size(); i += 20) {
-        Uint8 h[20];
-        memcpy(h, hash_string.data() + i, 20);
-        SHA1Hash hash(h);
+        SHA1Hash hash(hash_string_view.sliced(i, 20));
         hash_pieces.append(hash);
     }
 }
@@ -267,7 +257,7 @@ void Torrent::loadAnnounceList(BNode *node)
         BListNode *url_list = ml->getList(i);
         if (url_list) {
             for (Uint32 j = 0; j < url_list->getNumChildren(); j++)
-                tier->urls.append(QUrl(url_list->getString(j, nullptr)));
+                tier->urls.append(QUrl(url_list->getString(j)));
             tier->next = new TrackerTier();
             tier = tier->next;
         }
@@ -284,7 +274,7 @@ void Torrent::loadNodes(BListNode *node)
         // first child is the IP, second the port
         // add the DHT node
         DHTNode n;
-        n.ip = c->getString(0, nullptr);
+        n.ip = c->getString(0);
         n.port = c->getInt(1);
         nodes.append(n);
     }
@@ -293,7 +283,7 @@ void Torrent::loadNodes(BListNode *node)
 void Torrent::loadWebSeeds(BListNode *node)
 {
     for (Uint32 i = 0; i < node->getNumChildren(); i++) {
-        QUrl url = QUrl(node->getString(i, text_codec));
+        QUrl url = QUrl(node->getString(i));
         if (url.isValid())
             web_seeds.append(url);
     }
@@ -338,7 +328,7 @@ bool Torrent::verifyHash(const SHA1Hash &h, Uint32 index)
 const SHA1Hash &Torrent::getHash(Uint32 idx) const
 {
     if (idx >= (Uint32)hash_pieces.count())
-        throw Error(QString("Torrent::getHash %1 is out of bounds").arg(idx));
+        throw Error(u"Torrent::getHash %1 is out of bounds"_s.arg(idx));
 
     return hash_pieces[idx];
 }
@@ -451,21 +441,6 @@ bool Torrent::checkPathForDirectoryTraversal(const QString &p)
     return !sl.contains(QLatin1String(".."));
 }
 
-void Torrent::changeTextCodec(QTextCodec *codec)
-{
-    if (text_codec == codec)
-        return;
-
-    Out(SYS_GEN | LOG_DEBUG) << "Change Codec: " << QString(codec->name()) << endl;
-    text_codec = codec;
-    for (int i = 0; i < files.count(); i++) {
-        TorrentFile &f = files[i];
-        f.changeTextCodec(codec);
-    }
-    name_suggestion = text_codec->toUnicode(unencoded_name);
-    name_suggestion = SanityzeName(name_suggestion);
-}
-
 void Torrent::downloadPriorityChanged(TorrentFile *tf, Priority newpriority, Priority oldpriority)
 {
     if (file_prio_listener)
