@@ -9,9 +9,9 @@
 #include <QDateTime>
 #include <QDir>
 #include <QFile>
-#include <QTextCodec>
 #include <QTextStream>
 
+#include <KIO/CopyJob>
 #include <KLocalizedString>
 
 #include "choker.h"
@@ -42,7 +42,6 @@
 #include <interfaces/monitorinterface.h>
 #include <interfaces/queuemanagerinterface.h>
 #include <interfaces/trackerslist.h>
-#include <kio/copyjob.h>
 #include <net/socketmonitor.h>
 #include <peer/peer.h>
 #include <peer/peerdownloader.h>
@@ -54,6 +53,8 @@
 #include <util/log.h>
 #include <util/waitjob.h>
 
+using namespace Qt::Literals::StringLiterals;
+
 namespace bt
 {
 bool TorrentControl::completed_datacheck = false;
@@ -108,7 +109,7 @@ TorrentControl::~TorrentControl()
         tmon->destroyed();
 
     if (downloader)
-        downloader->saveWebSeeds(tordir + "webseeds");
+        downloader->saveWebSeeds(tordir + "webseeds"_L1);
 
     delete job_queue;
     delete choke;
@@ -300,7 +301,7 @@ void TorrentControl::pause()
     pman->pause();
 
     try {
-        downloader->saveDownloads(tordir + "current_chunks");
+        downloader->saveDownloads(tordir + "current_chunks"_L1);
     } catch (Error &e) {
         // print out warning in case of failure
         // it doesn't corrupt the data, so just a couple of lost chunks
@@ -308,7 +309,7 @@ void TorrentControl::pause()
     }
 
     downloader->pause();
-    downloader->saveWebSeeds(tordir + "webseeds");
+    downloader->saveWebSeeds(tordir + "webseeds"_L1);
     downloader->removeAllWebSeeds();
     cman->stop();
     stats.paused = true;
@@ -327,14 +328,14 @@ void TorrentControl::unpause()
     cman->start();
 
     try {
-        downloader->loadDownloads(tordir + "current_chunks");
+        downloader->loadDownloads(tordir + "current_chunks"_L1);
     } catch (Error &e) {
         // print out warning in case of failure
         // we can still continue the download
         Out(SYS_GEN | LOG_NOTICE) << "Warning : " << e.toString() << endl;
     }
 
-    downloader->loadWebSeeds(tordir + "webseeds");
+    downloader->loadWebSeeds(tordir + "webseeds"_L1);
     pman->unpause();
     loadStats();
     istats.time_started_ul = istats.time_started_dl = QDateTime::currentDateTime();
@@ -390,9 +391,9 @@ void TorrentControl::continueStart()
 {
     // continues start after the prealloc_thread has finished preallocation
     pman->start(stats.completed && stats.superseeding);
-    pman->loadPeerList(tordir + "peer_list");
+    pman->loadPeerList(tordir + "peer_list"_L1);
     try {
-        downloader->loadDownloads(tordir + "current_chunks");
+        downloader->loadDownloads(tordir + "current_chunks"_L1);
     } catch (Error &e) {
         // print out warning in case of failure
         // we can still continue the download
@@ -439,7 +440,7 @@ void TorrentControl::stop(WaitJob *wjob)
             tmon->stopped();
 
         try {
-            downloader->saveDownloads(tordir + "current_chunks");
+            downloader->saveDownloads(tordir + "current_chunks"_L1);
         } catch (Error &e) {
             // print out warning in case of failure
             // it doesn't corrupt the data, so just a couple of lost chunks
@@ -449,7 +450,7 @@ void TorrentControl::stop(WaitJob *wjob)
         downloader->clearDownloads();
     }
 
-    pman->savePeerList(tordir + "peer_list");
+    pman->savePeerList(tordir + "peer_list"_L1);
     pman->stop();
     cman->stop();
 
@@ -496,7 +497,7 @@ void TorrentControl::init(QueueManagerInterface *qman, const QByteArray &data, c
     initInternal(qman, tmpdir, ddir);
 
     // copy data into torrent file
-    QString tor_copy = tordir + "torrent";
+    QString tor_copy = tordir + "torrent"_L1;
     QFile fptr(tor_copy);
     if (!fptr.open(QIODevice::WriteOnly))
         throw Error(i18n("Unable to create %1: %2", tor_copy, fptr.errorString()));
@@ -548,9 +549,9 @@ void TorrentControl::setupStats()
 
     // check the stats file for the custom_output_name variable
     if (!stats_file)
-        stats_file = new StatsFile(tordir + "stats");
+        stats_file = new StatsFile(tordir + "stats"_L1);
 
-    if (stats_file->hasKey("CUSTOM_OUTPUT_NAME") && stats_file->readULong("CUSTOM_OUTPUT_NAME") == 1) {
+    if (stats_file->hasKey(u"CUSTOM_OUTPUT_NAME"_s) && stats_file->readULong(u"CUSTOM_OUTPUT_NAME"_s) == 1) {
         istats.custom_output_name = true;
     }
 
@@ -572,7 +573,7 @@ void TorrentControl::setupData()
     // Create chunkmanager, load the index file if it exists
     // else create all the necesarry files
     cman = new ChunkManager(*tor, tordir, outputdir, istats.custom_output_name, cache_factory);
-    if (bt::Exists(tordir + "index"))
+    if (bt::Exists(tordir + "index"_L1))
         cman->loadIndexFile();
 
     connect(cman, &ChunkManager::updateStats, this, &TorrentControl::updateStats);
@@ -581,7 +582,7 @@ void TorrentControl::setupData()
 
     // create downloader, uploader and choker
     downloader = new Downloader(*tor, *pman, *cman);
-    downloader->loadWebSeeds(tordir + "webseeds");
+    downloader->loadWebSeeds(tordir + "webseeds"_L1);
     connect(downloader, &Downloader::ioError, this, &TorrentControl::onIOError);
     connect(downloader, &Downloader::chunkDownloaded, this, &TorrentControl::downloaded);
     uploader = new Uploader(*cman, *pman);
@@ -599,7 +600,6 @@ void TorrentControl::initInternal(QueueManagerInterface *qman, const QString &tm
     checkExisting(qman);
     setupDirs(tmpdir, ddir);
     setupStats();
-    loadEncoding();
     setupData();
     updateStatus();
 
@@ -607,7 +607,7 @@ void TorrentControl::initInternal(QueueManagerInterface *qman, const QString &tm
     // the data from downloads already in progress
     try {
         Uint64 db = downloader->bytesDownloaded();
-        Uint64 cb = downloader->getDownloadedBytesOfCurrentChunksFile(tordir + "current_chunks");
+        Uint64 cb = downloader->getDownloadedBytesOfCurrentChunksFile(tordir + "current_chunks"_L1);
         istats.prev_bytes_dl = db + cb;
 
         //  Out() << "Downloaded : " << BytesToString(db) << endl;
@@ -893,63 +893,62 @@ void TorrentControl::saveStats()
         return;
 
     if (!stats_file)
-        stats_file = new StatsFile(tordir + "stats");
+        stats_file = new StatsFile(tordir + "stats"_L1);
 
-    stats_file->write("OUTPUTDIR", cman->getDataDir());
-    stats_file->write("COMPLETEDDIR", completed_dir);
+    stats_file->write(u"OUTPUTDIR"_s, cman->getDataDir());
+    stats_file->write(u"COMPLETEDDIR"_s, completed_dir);
 
     if (cman->getDataDir() != outputdir)
         outputdir = cman->getDataDir();
 
-    stats_file->write("UPLOADED", QString::number(uploader->bytesUploaded()));
+    stats_file->write(u"UPLOADED"_s, QString::number(uploader->bytesUploaded()));
 
     if (stats.running) {
         QDateTime now = QDateTime::currentDateTime();
         if (!stats.completed)
-            stats_file->write("RUNNING_TIME_DL", QString("%1").arg(istats.running_time_dl + istats.time_started_dl.secsTo(now)));
+            stats_file->write(u"RUNNING_TIME_DL"_s, QString::number(istats.running_time_dl + istats.time_started_dl.secsTo(now)));
         else
-            stats_file->write("RUNNING_TIME_DL", QString("%1").arg(istats.running_time_dl));
-        stats_file->write("RUNNING_TIME_UL", QString("%1").arg(istats.running_time_ul + istats.time_started_ul.secsTo(now)));
+            stats_file->write(u"RUNNING_TIME_DL"_s, QString::number(istats.running_time_dl));
+        stats_file->write(u"RUNNING_TIME_UL"_s, QString::number(istats.running_time_ul + istats.time_started_ul.secsTo(now)));
     } else {
-        stats_file->write("RUNNING_TIME_DL", QString("%1").arg(istats.running_time_dl));
-        stats_file->write("RUNNING_TIME_UL", QString("%1").arg(istats.running_time_ul));
+        stats_file->write(u"RUNNING_TIME_DL"_s, QString::number(istats.running_time_dl));
+        stats_file->write(u"RUNNING_TIME_UL"_s, QString::number(istats.running_time_ul));
     }
 
-    stats_file->write("QM_CAN_START", stats.qm_can_start ? "1" : "0");
-    stats_file->write("PRIORITY", QString("%1").arg(istats.priority));
-    stats_file->write("AUTOSTART", QString("%1").arg(stats.autostart));
-    stats_file->write("IMPORTED", QString("%1").arg(stats.imported_bytes));
-    stats_file->write("CUSTOM_OUTPUT_NAME", istats.custom_output_name ? "1" : "0");
-    stats_file->write("MAX_RATIO", QString("%1").arg(stats.max_share_ratio, 0, 'f', 2));
-    stats_file->write("MAX_SEED_TIME", QString::number(stats.max_seed_time));
-    stats_file->write("RESTART_DISK_PREALLOCATION", prealloc ? "1" : "0");
-    stats_file->write("AUTO_STOPPED", stats.auto_stopped ? "1" : "0");
+    stats_file->write(u"QM_CAN_START"_s, stats.qm_can_start ? u"1"_s : u"0"_s);
+    stats_file->write(u"PRIORITY"_s, QString::number(istats.priority));
+    stats_file->write(u"AUTOSTART"_s, QString::number(stats.autostart));
+    stats_file->write(u"IMPORTED"_s, QString::number(stats.imported_bytes));
+    stats_file->write(u"CUSTOM_OUTPUT_NAME"_s, istats.custom_output_name ? u"1"_s : u"0"_s);
+    stats_file->write(u"MAX_RATIO"_s, u"%1"_s.arg(stats.max_share_ratio, 0, 'f', 2));
+    stats_file->write(u"MAX_SEED_TIME"_s, QString::number(stats.max_seed_time));
+    stats_file->write(u"RESTART_DISK_PREALLOCATION"_s, prealloc ? u"1"_s : u"0"_s);
+    stats_file->write(u"AUTO_STOPPED"_s, stats.auto_stopped ? u"1"_s : u"0"_s);
 
     if (!stats.priv_torrent) {
         // save dht and pex
-        stats_file->write("DHT", isFeatureEnabled(DHT_FEATURE) ? "1" : "0");
-        stats_file->write("UT_PEX", isFeatureEnabled(UT_PEX_FEATURE) ? "1" : "0");
+        stats_file->write(u"DHT"_s, isFeatureEnabled(DHT_FEATURE) ? u"1"_s : u"0"_s);
+        stats_file->write(u"UT_PEX"_s, isFeatureEnabled(UT_PEX_FEATURE) ? u"1"_s : u"0"_s);
     }
 
-    stats_file->write("UPLOAD_LIMIT", QString::number(upload_limit));
-    stats_file->write("DOWNLOAD_LIMIT", QString::number(download_limit));
-    stats_file->write("ENCODING", QString(tor->getTextCodec()->name()));
-    stats_file->write("ASSURED_UPLOAD_SPEED", QString::number(assured_upload_speed));
-    stats_file->write("ASSURED_DOWNLOAD_SPEED", QString::number(assured_download_speed));
+    stats_file->write(u"UPLOAD_LIMIT"_s, QString::number(upload_limit));
+    stats_file->write(u"DOWNLOAD_LIMIT"_s, QString::number(download_limit));
+    stats_file->write(u"ASSURED_UPLOAD_SPEED"_s, QString::number(assured_upload_speed));
+    stats_file->write(u"ASSURED_DOWNLOAD_SPEED"_s, QString::number(assured_download_speed));
     if (!user_modified_name.isEmpty())
-        stats_file->write("USER_MODIFIED_NAME", user_modified_name);
-    stats_file->write("DISPLAY_NAME", display_name);
-    stats_file->write("URL", url.toDisplayString());
+        stats_file->write(u"USER_MODIFIED_NAME"_s, user_modified_name);
+    stats_file->write(u"DISPLAY_NAME"_s, display_name);
+    stats_file->write(u"URL"_s, url.toDisplayString());
 
-    stats_file->write("TIME_ADDED", QString("%1").arg(stats.time_added.toSecsSinceEpoch()));
-    stats_file->write("SUPERSEEDING", stats.superseeding ? "1" : "0");
+    stats_file->write(u"TIME_ADDED"_s, QString::number(stats.time_added.toSecsSinceEpoch()));
+    stats_file->write(u"SUPERSEEDING"_s, stats.superseeding ? u"1"_s : u"0"_s);
 
     stats_file->sync();
 }
 
 void TorrentControl::loadStats()
 {
-    if (!bt::Exists(tordir + "stats")) {
+    if (!bt::Exists(tordir + "stats"_L1)) {
         setFeatureEnabled(DHT_FEATURE, true);
         setFeatureEnabled(UT_PEX_FEATURE, true);
         return;
@@ -957,116 +956,94 @@ void TorrentControl::loadStats()
 
     RecursiveEntryGuard guard(&loading_stats);
     if (!stats_file)
-        stats_file = new StatsFile(tordir + "stats");
+        stats_file = new StatsFile(tordir + "stats"_L1);
 
-    Uint64 val = stats_file->readUint64("UPLOADED");
+    Uint64 val = stats_file->readUint64(u"UPLOADED"_s);
     // stats.session_bytes_uploaded will be calculated based upon prev_bytes_ul
     // seeing that this will change here, we need to save it
     istats.session_bytes_uploaded = stats.session_bytes_uploaded;
     istats.prev_bytes_ul = val;
     uploader->setBytesUploaded(val);
 
-    istats.running_time_dl = stats_file->readULong("RUNNING_TIME_DL");
-    istats.running_time_ul = stats_file->readULong("RUNNING_TIME_UL");
+    istats.running_time_dl = stats_file->readULong(u"RUNNING_TIME_DL"_s);
+    istats.running_time_ul = stats_file->readULong(u"RUNNING_TIME_UL"_s);
     // make sure runtime ul is always equal or largen then running time dl
     // in case something got corrupted
     if (istats.running_time_ul < istats.running_time_dl)
         istats.running_time_ul = istats.running_time_dl;
 
-    outputdir = stats_file->readString("OUTPUTDIR").trimmed();
-    if (stats_file->hasKey("CUSTOM_OUTPUT_NAME") && stats_file->readULong("CUSTOM_OUTPUT_NAME") == 1) {
+    outputdir = stats_file->readString(u"OUTPUTDIR"_s).trimmed();
+    if (stats_file->hasKey(u"CUSTOM_OUTPUT_NAME"_s) && stats_file->readULong(u"CUSTOM_OUTPUT_NAME"_s) == 1) {
         istats.custom_output_name = true;
     }
 
-    if (stats_file->hasKey("COMPLETEDDIR")) {
-        completed_dir = stats_file->readString("COMPLETEDDIR");
+    if (stats_file->hasKey(u"COMPLETEDDIR"_s)) {
+        completed_dir = stats_file->readString(u"COMPLETEDDIR"_s);
         if (completed_dir == outputdir)
             completed_dir = QString();
     }
 
-    if (stats_file->hasKey("USER_MODIFIED_NAME"))
-        user_modified_name = stats_file->readString("USER_MODIFIED_NAME");
+    if (stats_file->hasKey(u"USER_MODIFIED_NAME"_s))
+        user_modified_name = stats_file->readString(u"USER_MODIFIED_NAME"_s);
 
-    if (stats_file->hasKey("DISPLAY_NAME"))
-        display_name = stats_file->readString("DISPLAY_NAME");
+    if (stats_file->hasKey(u"DISPLAY_NAME"_s))
+        display_name = stats_file->readString(u"DISPLAY_NAME"_s);
 
-    istats.priority = stats_file->readInt("PRIORITY");
-    stats.autostart = stats_file->readBoolean("AUTOSTART");
-    stats.imported_bytes = stats_file->readUint64("IMPORTED");
-    stats.max_share_ratio = stats_file->readFloat("MAX_RATIO");
-    stats.max_seed_time = stats_file->readFloat("MAX_SEED_TIME");
-    stats.qm_can_start = stats_file->readBoolean("QM_CAN_START");
-    stats.auto_stopped = stats_file->readBoolean("AUTO_STOPPED");
+    istats.priority = stats_file->readInt(u"PRIORITY"_s);
+    stats.autostart = stats_file->readBoolean(u"AUTOSTART"_s);
+    stats.imported_bytes = stats_file->readUint64(u"IMPORTED"_s);
+    stats.max_share_ratio = stats_file->readFloat(u"MAX_RATIO"_s);
+    stats.max_seed_time = stats_file->readFloat(u"MAX_SEED_TIME"_s);
+    stats.qm_can_start = stats_file->readBoolean(u"QM_CAN_START"_s);
+    stats.auto_stopped = stats_file->readBoolean(u"AUTO_STOPPED"_s);
 
-    if (stats_file->hasKey("RESTART_DISK_PREALLOCATION"))
-        prealloc = stats_file->readString("RESTART_DISK_PREALLOCATION") == "1";
+    if (stats_file->hasKey(u"RESTART_DISK_PREALLOCATION"_s))
+        prealloc = stats_file->readString(u"RESTART_DISK_PREALLOCATION"_s) == '1'_L1;
 
     if (!stats.priv_torrent) {
-        if (stats_file->hasKey("DHT"))
-            istats.dht_on = stats_file->readBoolean("DHT");
+        if (stats_file->hasKey(u"DHT"_s))
+            istats.dht_on = stats_file->readBoolean(u"DHT"_s);
         else
             istats.dht_on = true;
 
         setFeatureEnabled(DHT_FEATURE, istats.dht_on);
-        if (stats_file->hasKey("UT_PEX"))
-            setFeatureEnabled(UT_PEX_FEATURE, stats_file->readBoolean("UT_PEX"));
+        if (stats_file->hasKey(u"UT_PEX"_s))
+            setFeatureEnabled(UT_PEX_FEATURE, stats_file->readBoolean(u"UT_PEX"_s));
     }
 
-    QString codec = stats_file->readString("ENCODING");
-    if (codec.length() > 0) {
-        QTextCodec *cod = QTextCodec::codecForName(codec.toLocal8Bit());
-        if (cod)
-            changeTextCodec(cod);
-    }
-
-    Uint32 aup = stats_file->readInt("ASSURED_UPLOAD_SPEED");
-    Uint32 adown = stats_file->readInt("ASSURED_DOWNLOAD_SPEED");
-    Uint32 up = stats_file->readInt("UPLOAD_LIMIT");
-    Uint32 down = stats_file->readInt("DOWNLOAD_LIMIT");
+    Uint32 aup = stats_file->readInt(u"ASSURED_UPLOAD_SPEED"_s);
+    Uint32 adown = stats_file->readInt(u"ASSURED_DOWNLOAD_SPEED"_s);
+    Uint32 up = stats_file->readInt(u"UPLOAD_LIMIT"_s);
+    Uint32 down = stats_file->readInt(u"DOWNLOAD_LIMIT"_s);
     setDownloadProps(down, adown);
     setUploadProps(up, aup);
     pman->setGroupIDs(upload_gid, download_gid);
 
-    url = QUrl(stats_file->readString("URL"));
+    url = QUrl(stats_file->readString(u"URL"_s));
 
-    if (stats_file->hasKey("TIME_ADDED"))
-        stats.time_added.setSecsSinceEpoch(stats_file->readULong("TIME_ADDED"));
+    if (stats_file->hasKey(u"TIME_ADDED"_s))
+        stats.time_added.setSecsSinceEpoch(stats_file->readULong(u"TIME_ADDED"_s));
     else
         stats.time_added = QDateTime::currentDateTime();
 
-    bool ss = stats_file->hasKey("SUPERSEEDING") && stats_file->readBoolean("SUPERSEEDING");
+    bool ss = stats_file->hasKey(u"SUPERSEEDING"_s) && stats_file->readBoolean(u"SUPERSEEDING"_s);
     setSuperSeeding(ss);
 }
 
 void TorrentControl::loadOutputDir()
 {
     if (!stats_file)
-        stats_file = new StatsFile(tordir + "stats");
+        stats_file = new StatsFile(tordir + "stats"_L1);
 
-    if (!stats_file->hasKey("OUTPUTDIR"))
+    if (!stats_file->hasKey(u"OUTPUTDIR"_s))
         return;
 
-    outputdir = stats_file->readString("OUTPUTDIR").trimmed();
-    if (stats_file->hasKey("CUSTOM_OUTPUT_NAME") && stats_file->readULong("CUSTOM_OUTPUT_NAME") == 1) {
+    outputdir = stats_file->readString(u"OUTPUTDIR"_s).trimmed();
+    if (stats_file->hasKey(u"CUSTOM_OUTPUT_NAME"_s) && stats_file->readULong(u"CUSTOM_OUTPUT_NAME"_s) == 1) {
         istats.custom_output_name = true;
     }
 }
 
-void TorrentControl::loadEncoding()
-{
-    if (!stats_file)
-        stats_file = new StatsFile(tordir + "stats");
-    if (!stats_file->hasKey("ENCODING"))
-        return;
-
-    QString codec = stats_file->readString("ENCODING");
-    if (codec.length() > 0) {
-        QTextCodec *cod = QTextCodec::codecForName(codec.toLocal8Bit());
-        if (cod)
-            changeTextCodec(cod);
-    }
-}
-
 bool TorrentControl::readyForPreview() const
 {
     if (tor->isMultiFile() || !tor->isMultimedia())
@@ -1128,8 +1105,8 @@ void TorrentControl::trackerScrapeDone()
 
 void TorrentControl::afterRename()
 {
-    stats_file->write("OUTPUTDIR", cman->getDataDir());
-    stats_file->write("USER_MODIFIED_NAME", user_modified_name);
+    stats_file->write(u"OUTPUTDIR"_s, cman->getDataDir());
+    stats_file->write(u"USER_MODIFIED_NAME"_s, user_modified_name);
     stats_file->sync();
     cman->saveFileMap();
 }
@@ -1204,9 +1181,9 @@ void TorrentControl::setPriority(int p)
 {
     istats.priority = p;
     if (!stats_file)
-        stats_file = new StatsFile(tordir + "stats");
+        stats_file = new StatsFile(tordir + "stats"_L1);
 
-    stats_file->write("PRIORITY", QString("%1").arg(istats.priority));
+    stats_file->write(u"PRIORITY"_s, QString::number(istats.priority));
     updateStatus();
 }
 
@@ -1613,22 +1590,6 @@ void TorrentControl::preallocFinished(const QString &error, bool completed)
     }
 }
 
-const QTextCodec *TorrentControl::getTextCodec() const
-{
-    if (!tor)
-        return nullptr;
-    else
-        return tor->getTextCodec();
-}
-
-void TorrentControl::changeTextCodec(QTextCodec *tc)
-{
-    if (tor) {
-        tor->changeTextCodec(tc);
-        stats.torrent_name = tor->getNameSuggestion();
-    }
-}
-
 void TorrentControl::setCacheFactory(CacheFactory *cf)
 {
     cache_factory = cf;
@@ -1653,7 +1614,7 @@ bool TorrentControl::addWebSeed(const QUrl &url)
 {
     WebSeed *ws = downloader->addWebSeed(url);
     if (ws) {
-        downloader->saveWebSeeds(tordir + "webseeds");
+        downloader->saveWebSeeds(tordir + "webseeds"_L1);
         ws->setGroupIDs(upload_gid, download_gid); // make sure webseed has proper group ID
     }
     return ws != nullptr;
@@ -1663,7 +1624,7 @@ bool TorrentControl::removeWebSeed(const QUrl &url)
 {
     bool ret = downloader->removeWebSeed(url);
     if (ret)
-        downloader->saveWebSeeds(tordir + "webseeds");
+        downloader->saveWebSeeds(tordir + "webseeds"_L1);
     return ret;
 }
 
